:tocdepth: 2

========================
Messaging Service API v2
========================

This is a reference for the OpenStack Messaging Service API which is provided
by the Zaqar project.

.. rest_expand_all::

.. include:: versions.inc
.. include:: queues.inc
.. include:: messages.inc
.. include:: claims.inc
.. include:: subscription.inc
.. include:: health.inc
.. include:: pools.inc
.. include:: flavors.inc
